@@ -28,7 +28,8 @@ def _history():
 
 
 def _feed_cli_with_input(text, editing_mode=EditingMode.EMACS, clipboard=None,
-                         history=None, multiline=False):
+                         history=None, multiline=False, check_line_ending=True,
+                         pre_run_callback=None):
     """
     Create a CommandLineInterface, feed it with the given user input and return
     the CLI object.
@@ -36,7 +37,8 @@ def _feed_cli_with_input(text, editing_mode=EditingMode.EMACS, clipboard=None,
     This returns a (result, CLI) tuple.
     """
     # If the given text doesn't end with a newline, the interface won't finish.
-    assert text.endswith('\n')
+    if check_line_ending:
+        assert text.endswith('\n')
 
     loop = PosixEventLoop()
     try:
@@ -53,6 +55,10 @@ def _feed_cli_with_input(text, editing_mode=EditingMode.EMACS, clipboard=None,
             eventloop=loop,
             input=inp,
             output=DummyOutput())
+
+        if pre_run_callback:
+            pre_run_callback(cli)
+
         result = cli.run()
         return result, cli
     finally:
@@ -203,7 +209,7 @@ def test_emacs_yank():
     c = InMemoryClipboard(ClipboardData('XYZ'))
     result, cli = _feed_cli_with_input('hello\x02\x19\n', clipboard=c)
     assert result.text == 'hellXYZo'
-    assert result.cursor_position == len('hellXY')
+    assert result.cursor_position == len('hellXYZ')
 
 
 def test_quoted_insert():
@@ -252,14 +258,30 @@ def test_emacs_other_bindings():
     result, cli = _feed_cli_with_input('hello\x1b[D\x1b[D\x15X\n')
     assert result.text == 'Xlo'
 
-    # Delete word before the cursor.
+    # unix-word-rubout: delete word before the cursor.
+    # (ControlW).
     result, cli = _feed_cli_with_input('hello world test\x17X\n')
     assert result.text == 'hello world X'
 
+    result, cli = _feed_cli_with_input('hello world /some/very/long/path\x17X\n')
+    assert result.text == 'hello world X'
+
     # (with argument.)
     result, cli = _feed_cli_with_input('hello world test\x1b2\x17X\n')
     assert result.text == 'hello X'
 
+    result, cli = _feed_cli_with_input('hello world /some/very/long/path\x1b2\x17X\n')
+    assert result.text == 'hello X'
+
+    # backward-kill-word: delete word before the cursor.
+    # (Esc-ControlH).
+    result, cli = _feed_cli_with_input('hello world /some/very/long/path\x1b\x08X\n')
+    assert result.text == 'hello world /some/very/long/X'
+
+    # (with arguments.)
+    result, cli = _feed_cli_with_input('hello world /some/very/long/path\x1b3\x1b\x08X\n')
+    assert result.text == 'hello world /some/very/X'
+
 
 def test_controlx_controlx():
     # At the end: go to the start of the line.
@@ -368,6 +390,72 @@ def test_emacs_arguments_for_all_commands():
                 assert key == '\x03'
 
 
+def test_emacs_kill_ring():
+    operations = (
+        # abc ControlA ControlK
+        'abc\x01\x0b'
+
+        # def ControlA ControlK
+        'def\x01\x0b'
+
+        # ghi ControlA ControlK
+        'ghi\x01\x0b'
+
+        # ControlY (yank)
+        '\x19'
+    )
+
+    result, cli = _feed_cli_with_input(operations + '\n')
+    assert result.text == 'ghi'
+
+    result, cli = _feed_cli_with_input(operations + '\x1by\n')
+    assert result.text == 'def'
+
+    result, cli = _feed_cli_with_input(operations + '\x1by\x1by\n')
+    assert result.text == 'abc'
+
+    result, cli = _feed_cli_with_input(operations + '\x1by\x1by\x1by\n')
+    assert result.text == 'ghi'
+
+
+def test_emacs_insert_comment():
+    # Test insert-comment (M-#) binding.
+    result, cli = _feed_cli_with_input('hello\x1b#', check_line_ending=False)
+    assert result.text == '#hello'
+
+    result, cli = _feed_cli_with_input(
+        'hello\nworld\x1b#', check_line_ending=False, multiline=True)
+    assert result.text == '#hello\n#world'
+
+
+def test_emacs_record_macro():
+    operations = (
+        '  '
+        '\x18('  # Start recording macro. C-X(
+        'hello'
+        '\x18)'  # Stop recording macro.
+        '  '
+        '\x18e'  # Execute macro.
+        '\x18e'  # Execute macro.
+        '\n'
+    )
+
+    result, cli = _feed_cli_with_input(operations)
+    assert result.text == '  hello  hellohello'
+
+
+def test_prefix_meta():
+    # Test the prefix-meta command.
+    def setup_keybindings(cli):
+        from prompt_toolkit.key_binding.bindings.named_commands import prefix_meta
+        from prompt_toolkit.filters import ViInsertMode
+        cli.application.key_bindings_registry.add_binding('j', 'j', filter=ViInsertMode())(prefix_meta)
+
+    result, cli = _feed_cli_with_input(
+        'hellojjIX\n', pre_run_callback=setup_keybindings, editing_mode=EditingMode.VI)
+    assert result.text == 'Xhello'
+
+
 def test_bracketed_paste():
     result, cli = _feed_cli_with_input('\x1b[200~hello world\x1b[201~\n')
     assert result.text == 'hello world'
@@ -478,7 +566,7 @@ def test_vi_digraphs():
     result, cli = feed('hello\x0bo/\n')
     assert result.text == 'helloø'
 
-    #C-K /o  (reversed input.)
+    # C-K /o  (reversed input.)
     result, cli = feed('hello\x0b/o\n')
     assert result.text == 'helloø'
 
@@ -518,10 +606,24 @@ def test_vi_block_editing():
     result, cli = feed(operations.replace('insert', 'I'))
 
     assert (result.text ==
-        '-line1\n-***line2\n-***line3\n-***line4\n-line5\n-line6')
+            '-line1\n-***line2\n-***line3\n-***line4\n-line5\n-line6')
 
     # Control-A
     result, cli = feed(operations.replace('insert', 'A'))
 
     assert (result.text ==
-        '-line1\n-line***2\n-line***3\n-line***4\n-line5\n-line6')
+            '-line1\n-line***2\n-line***3\n-line***4\n-line5\n-line6')
+
+
+def test_vi_character_paste():
+    feed = partial(_feed_cli_with_input, editing_mode=EditingMode.VI)
+
+    # Test 'p' character paste.
+    result, cli = feed('abcde\x1bhhxp\n')
+    assert result.text == 'abdce'
+    assert result.cursor_position == 3
+
+    # Test 'P' character paste.
+    result, cli = feed('abcde\x1bhhxP\n')
+    assert result.text == 'abcde'
+    assert result.cursor_position == 2
